# Durak
Durak (*дурак* – fool) is a static site generator with its own templating system, that makes
automatization of burdensome tasks, such as updating article listings on a blog, easy.
An example blog can be found in the [`examples/blog`](examples/blog/) directory. To see the
HTML generated from the example sources, run `durak examples/blog examples/blog_output` and open
`examples/blog_output/index.html` in a web browser.

# Installation
```
python3 -m pip install durak
```

# Documentation
See the [`docs/README.md`](docs/README.md) file.
